# Zendesk Talk changelog

## [0.1.10] - 2026-04-01
- Updated connector definition (YAML version 1.0.1)
- Source commit: e4c74933
- SDK version: 0.1.0

## [0.1.9] - 2026-04-01
- Updated connector definition (YAML version 1.0.1)
- Source commit: 513344c6
- SDK version: 0.1.0

## [0.1.8] - 2026-03-26
- Updated connector definition (YAML version 1.0.1)
- Source commit: 75f38884
- SDK version: 0.1.0

## [0.1.7] - 2026-03-26
- Updated connector definition (YAML version 1.0.1)
- Source commit: 20f00dda
- SDK version: 0.1.0

## [0.1.6] - 2026-03-25
- Updated connector definition (YAML version 1.0.1)
- Source commit: bbb46256
- SDK version: 0.1.0

## [0.1.5] - 2026-03-23
- Updated connector definition (YAML version 1.0.1)
- Source commit: 6ad04bc3
- SDK version: 0.1.0

## [0.1.4] - 2026-03-23
- Updated connector definition (YAML version 1.0.1)
- Source commit: 5718dee3
- SDK version: 0.1.0

## [0.1.3] - 2026-03-19
- Updated connector definition (YAML version 1.0.1)
- Source commit: 8416af10
- SDK version: 0.1.0

## [0.1.2] - 2026-03-12
- Updated connector definition (YAML version 1.0.0)
- Source commit: b541ca65
- SDK version: 0.1.0

## [0.1.1] - 2026-03-11
- Updated connector definition (YAML version 1.0.0)
- Source commit: 44677ecb
- SDK version: 0.1.0

## [0.1.0] - 2026-03-09
- Updated connector definition (YAML version 1.0.0)
- Source commit: 8908ac87
- SDK version: 0.1.0
